@@ -64,6 +64,10 @@ class HyperTorch:
         # type information and transformations are considered in generate_one_config_from_var_dict:
         for config in generate_one_config_from_var_dict(var_dict, self.fun_control):
             print(f"\nconfig: {config}")
+            config_id = ""
+            for key in config:
+                config_id += str(config[key]) + "_"
+            config_id = config_id[:-1]
             if self.fun_control["prep_model"] is not None:
                 model = make_pipeline(self.fun_control["prep_model"], self.fun_control["core_model"](**config))
             else:
@@ -76,6 +80,9 @@ class HyperTorch:
                         shuffle=self.fun_control["shuffle"],
                         device=self.fun_control["device"],
                         show_batch_interval=self.fun_control["show_batch_interval"],
+                        task=self.fun_control["task"],
+                        writer=self.fun_control["writer"],
+                        writerId=config_id,
                     )
                 elif self.fun_control["eval"] == "test_cv":
                     df_eval, _ = evaluate_cv(
@@ -84,31 +91,47 @@ class HyperTorch:
                         shuffle=self.fun_control["shuffle"],
                         device=self.fun_control["device"],
                         show_batch_interval=self.fun_control["show_batch_interval"],
+                        task=self.fun_control["task"],
+                        writer=self.fun_control["writer"],
+                        writerId=config_id,
                     )
                 elif self.fun_control["eval"] == "test_hold_out":
                     df_eval, _ = evaluate_hold_out(
                         model,
                         train_dataset=fun_control["train"],
                         shuffle=self.fun_control["shuffle"],
+                        loss_function=self.fun_control["loss_function"],
+                        metric=self.fun_control["metric_torch"],
                         test_dataset=fun_control["test"],
                         device=self.fun_control["device"],
                         show_batch_interval=self.fun_control["show_batch_interval"],
                         path=self.fun_control["path"],
-                        save_model=self.fun_control["save_model"],
+                        task=self.fun_control["task"],
+                        writer=self.fun_control["writer"],
+                        writerId=config_id,
                     )
                 else:  # eval == "train_hold_out"
                     df_eval, _ = evaluate_hold_out(
                         model,
                         train_dataset=fun_control["train"],
                         shuffle=self.fun_control["shuffle"],
+                        loss_function=self.fun_control["loss_function"],
+                        metric=self.fun_control["metric_torch"],
                         device=self.fun_control["device"],
                         show_batch_interval=self.fun_control["show_batch_interval"],
                         path=self.fun_control["path"],
-                        save_model=self.fun_control["save_model"],
+                        task=self.fun_control["task"],
+                        writer=self.fun_control["writer"],
+                        writerId=config_id,
                     )
             except Exception as err:
                 print(f"Error in fun_torch(). Call to evaluate_model failed. {err=}, {type(err)=}")
                 print("Setting df_eval to np.nan")
                 df_eval = np.nan
-            z_res = np.append(z_res, fun_control["weights"] * df_eval)
+            z_val = fun_control["weights"] * df_eval
+            if self.fun_control["writer"] is not None:
+                writer = self.fun_control["writer"]
+                writer.add_hparams(config, {"fun_torch: loss": z_val})
+                writer.flush()
+            z_res = np.append(z_res, z_val)
         return z_res
